Struct ZwpInputTimestampsV1
pub struct ZwpInputTimestampsV1 { /* private fields */ }wayland and Linux only.Expand description
context object for input timestamps
Provides high-resolution timestamp events for a set of subscribed input events. The set of subscribed input events is determined by the zwp_input_timestamps_manager_v1 request used to create this object.
See also the Request enum for this interface.
Implementations
impl ZwpInputTimestampsV1
impl ZwpInputTimestampsV1
pub fn timestamp(&self, tv_sec_hi: u32, tv_sec_lo: u32, tv_nsec: u32)
pub fn timestamp(&self, tv_sec_hi: u32, tv_sec_lo: u32, tv_nsec: u32)
high-resolution timestamp event
The timestamp event is associated with the first subsequent input event carrying a timestamp which belongs to the set of input events this object is subscribed to.
The timestamp provided by this event is a high-resolution version of the timestamp argument of the associated input event. The provided timestamp is in the same clock domain and is at least as accurate as the associated input event timestamp.
The timestamp is expressed as tv_sec_hi, tv_sec_lo, tv_nsec triples, each component being an unsigned 32-bit value. Whole seconds are in tv_sec which is a 64-bit value combined from tv_sec_hi and tv_sec_lo, and the additional fractional part in tv_nsec as nanoseconds. Hence, for valid timestamps tv_nsec must be in [0, 999999999].